==> winzig-0.2.8.tar.gz: winzig-0.2.8/winzig/commands/crawl.py <==
import asyncio
from pathlib import Path
import click
from sqlalchemy.ext.asyncio import AsyncSession
from winzig.crawler import crawl_from_feeds, crawl_links
from winzig.tf_idf import recalculate_tf_idf


@click.group(
    invoke_without_command=True,
    help="Crawl and extract content from feeds and posts. If no subcommand is provided, it automatically crawls previously saved feeds by default.",
)
@click.pass_context
def crawl(ctx):
    if ctx.invoked_subcommand is None:
        asyncio.run(_crawl_feeds(ctx.obj["engine"], None, None))


@click.command(
    name="feeds",
    help="Crawl and extract content from the posts of the specified feeds.",
)
@click.option(
    "-f",
    "--file",
    type=Path,
    default=None,
    help="Path to the file containing feed sources. If empty, previous feeds added to the database will be used.",
)
@click.option(
    "-m",
    "--max",
    type=int,
    default=None,
    help="Maximum number of posts to crawl from each feed.",
)
@click.pass_context
def crawl_feeds(ctx, file: Path, max: int):
    asyncio.run(_crawl_feeds(ctx.obj["engine"], file, max))


async def _crawl_feeds(engine, file: Path | None, max: int | None):
    async with AsyncSession(engine) as session:
        await crawl_from_feeds(
            session,
            file,
            max,
        )
        await recalculate_tf_idf(session)


@click.command(
    name="posts",
    help="Crawl and extract content from the posts specified in a file.",
)
@click.option(
    "-f",
    "--file",
    type=Path,
    help="Path to the file containing the links to crawl.",
)
@click.pass_context
def crawl_posts(ctx, file: Path):
    asyncio.run(_crawl_posts(ctx.obj["engine"], file))


async def _crawl_posts(engine, file: Path):
    async with AsyncSession(engine) as session:
        await crawl_links(session, file)
        await recalculate_tf_idf(session)


crawl.add_command(crawl_posts)
crawl.add_command(crawl_feeds)

==> winzig-0.2.15.tar.gz: winzig-0.2.15/winzig/commands/crawl.py <==
import asyncio
import click
from sqlalchemy.ext.asyncio import AsyncSession
from winzig.crawler import crawl_from_feeds, crawl_links
from winzig.tf_idf import recalculate_tf_idf
from winzig.console import console


@click.group(
    invoke_without_command=True,
    help="Crawl and extract content from feeds and posts. If no subcommand is provided, it automatically crawls previously saved feeds by default.",
)
@click.pass_context
def crawl(ctx):
    if ctx.invoked_subcommand is None:
        asyncio.run(_crawl_feeds(ctx.obj["engine"], [], None))


@click.command(
    name="feeds",
    help="Crawl and extract content from the posts of the specified feeds.",
)
@click.option(
    "-f",
    "--file",
    type=click.File(),
    default=None,
    help="Path to the file containing feed sources. If empty, previous feeds added to the database will be used.",
)
@click.option(
    "-m",
    "--max",
    type=int,
    default=None,
    help="Maximum number of posts to crawl from each feed.",
)
@click.argument("urls", nargs=-1)
@click.pass_context
def crawl_feeds(ctx, file, urls, max):
    feed_urls = []

    if file:
        feed_urls.extend(file.read().splitlines())

    if urls:
        feed_urls.extend(urls)

    asyncio.run(_crawl_feeds(ctx.obj["engine"], feed_urls, max))


async def _crawl_feeds(engine, urls: list, max: int | None):
    async with AsyncSession(engine) as session:
        await crawl_from_feeds(
            session,
            urls,
            max,
        )
        await recalculate_tf_idf(session)


@click.command(
    name="posts",
    help="Crawl and extract content from the posts specified in a file.",
)
@click.option(
    "-f",
    "--file",
    type=click.File(),
    help="Path to the file containing the links to crawl.",
)
@click.argument("urls", nargs=-1)
@click.pass_context
def crawl_posts(ctx, file, urls):
    post_urls = []

    if file:
        post_urls.extend(file.read().splitlines())

    if urls:
        post_urls.extend(urls)

    asyncio.run(_crawl_posts(ctx.obj["engine"], post_urls))


async def _crawl_posts(engine, urls: list):
    async with AsyncSession(engine) as session:
        await crawl_links(session, urls)
        await recalculate_tf_idf(session)


crawl.add_command(crawl_posts)
crawl.add_command(crawl_feeds)
